#!/usr/bin/env/python
# Tells Linux systems how to run this file.

"""
Morningside Human Interface
Purpose: Provide a convenient way for a human to play in Morningside.


How to use it:
Be sure that the path below, in the constants section, points to the player_io
directory.
Type text commands.
"""

__author__ = "Kris Schnee"
__version__ = "2009.9.26"
__license__ = "Public Domain"

##### Imported Modules #####

## Standard
import os
import time
import random

## Third-party


## Mine


##### Constants #####

"""
The path needs to reference the Morningside program's player_io folder.
Make sure that a file called path.txt is in this AI program's directory, and
that it consists of the appropriate path, eg. "C:\Code\Morningside\player_io".
"""
f = open("path.txt","r")
path = f.read()
f.close()
WORLDSIM_IO_PATH = path

DEFAULT_NAME = "Kris"

QUIT_COMMANDS = ("quit","exit","q")

##### Classes #####

class Interface:
    def __init__(self,**options):
        self.name = options.get("name",DEFAULT_NAME)

        """Filenames used for IO.
        The AI will look for text files in a certain path as input,
        and send its output as a text file in that same directory."""
        
        self.input_filename = "to_"+self.name.lower()+".txt"
        self.output_filename = "from_"+self.name.lower()+".txt"
        self.input_path = os.path.join(WORLDSIM_IO_PATH,self.input_filename)
        self.login_path = os.path.join(WORLDSIM_IO_PATH,"login_"+self.name.lower()+".txt")
        self.output_path = os.path.join(WORLDSIM_IO_PATH,self.output_filename)
        self.action = None ## What shall I do this round?

    def CheckForInput(self):
        print "Searching for input file."
        if os.path.exists(self.input_path):
            f = open(self.input_path,"r")
            text = f.read()
            f.close()
            os.remove(self.input_path)
            return text
        return None

    def PickAction(self):
        self.action = raw_input("Command? > ")
        if self.action.startswith("\"") or self.action.startswith("'"):
            self.action = "say "+self.action[1:]
        if self.action.startswith("say"):
            if self.action[-1] not in ".?!":
                self.action += "."

    def WriteOutput(self):
        if self.action in ("","i"):
            self.action = "idle"
        elif self.action in ("n","s","e","w"):
            self.action = "go "+self.action
        text = self.action
        f = open(self.output_path,"w")        
        f.write(text)
        f.close()

    def WriteLoginFile(self):
        if os.path.exists(self.login_path):
            print "My login file exists already. Using it."
        else:
            print "Writing a login file for myself."
            f = open("login_"+self.name.lower()+".txt","r")
            text = f.read()
            f.close()
            f = open(self.login_path,"w")
            f.write(text)
            f.close()

    def MainLoop(self):
        done = False
        text = ""
        self.WriteLoginFile()
        print "Ready and waiting for input from the worldsim."
        while True:
            while not text:
                time.sleep(1.0)
                text = self.CheckForInput()
            print "Got an input file that says:"
            print text.replace("|","\n")
            text = ""

            self.PickAction()
            if self.action in QUIT_COMMANDS:
                break
            self.WriteOutput()
            
        print "Done."


##### Other Functions #####



##### Autorun #####

if __name__ == "__main__":
    ## Runs if this module is the main module (not imported).
    login_files = [f for f in os.listdir(os.getcwd()) if f.startswith("login")]
    if not login_files:
        print "Creating a default local login file."
        f = open("login_[subject name here].txt","w")
        f.write("image: emmer\ncolor: yellow")
        f.close()
        name = "[Subject Name Here]"
    else:
        name = login_files[0].split(".")[0][6:]
        print name
        print os.listdir(os.getcwd())
    i = Interface(name=name)
    i.MainLoop()
